/*
 * ar_oxygen_monitor.c
 *
 *  Created on:
 *      Author:
 */

#include <stdio.h>
#include "stm32h7xx_hal.h"
#include "EV600A_ventilator.h"
#include "EV600A_common.h"
#include "EV600A_valdisplay.h"
#include "EV600A_ventalarms.h"
#include "EV600A_ventsettings.h"
#include "EV600A_ventask.h"
#include "EV600A_ventalarms.h"
#include "main.h"
#include "GUI_Paint.h"

// Display Values
lv_valdisplay TEMP_VAL;
lv_valdisplay HUMIDITY_VAL;
lv_valdisplay BPM_VAL;
lv_valdisplay SPO2_VAL;
lv_valdisplay ppeakval;
lv_valdisplay triggerval;
lv_valdisplay modeval;

//sw on/off
lv_obj_t *GAS_ON_OFF;
lv_obj_t *FIO2_ON_OFF;

 lv_obj_t *ie_bar;
lv_obj_t *vt_bar;
 lv_obj_t *rr_bar;
lv_obj_t *pip_bar;
lv_obj_t *peep_bar;
lv_obj_t *trigger_bar;


void ARIES_applychartstyles(lv_obj_t *chrt)
{
	static lv_style_t chart_style;
	lv_style_init(&chart_style);
	lv_style_set_pad_left(&chart_style,LV_STATE_DEFAULT,75);
	lv_obj_set_style_local_size(chrt, LV_CHART_PART_SERIES, LV_STATE_DEFAULT, 0);
	lv_obj_set_style_local_line_width(chrt, LV_CHART_PART_SERIES, LV_STATE_DEFAULT, 2);
	lv_obj_set_style_local_line_color(chrt, LV_CHART_AXIS_PRIMARY_Y, LV_STATE_DEFAULT, LV_COLOR_WHITE);
	lv_obj_set_style_local_line_color(chrt, LV_CHART_PART_SERIES_BG, LV_STATE_DEFAULT, LV_COLOR_WHITE);
	lv_obj_add_style(chrt,LV_CHART_PART_BG ,&chart_style);
	lv_obj_set_style_local_text_font(chrt, LV_CHART_AXIS_PRIMARY_Y, LV_STATE_DEFAULT, lv_theme_get_font_small());
    lv_obj_set_style_local_bg_color(chrt, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);
    lv_obj_set_style_local_border_width(chrt, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,0);
    lv_chart_set_div_line_count(chrt, 1,0);
}

void set_parameter_button(lv_obj_t *btn)
{
  lv_obj_set_style_local_value_font(btn, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_20);
  lv_obj_set_style_local_value_color(btn, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);
  lv_obj_set_style_local_border_color(btn, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, EV600A_MONITOR_RECTANGLE_OUTLINE);
  lv_obj_set_style_local_bg_color(btn, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, EV600A_MONITOR_RECTANGLE);
  lv_obj_set_style_local_bg_color(btn, LV_OBJ_PART_MAIN, LV_STATE_PRESSED, EV600A_MONITOR_RECTANGLE);
  lv_obj_set_style_local_border_width(btn, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,2);
  lv_obj_set_style_local_border_width(btn, LV_OBJ_PART_MAIN, LV_STATE_FOCUSED,2);
}

static void GAS_sw_event_handler(lv_obj_t * obj, lv_event_t event)
{
    if(event == LV_EVENT_VALUE_CHANGED) {
    	if(lv_switch_get_state(obj))
    		gas_sw_toggle = 1;
    	else
    		gas_sw_toggle = 0;
    }
}

static void FIO2_sw_event_handler(lv_obj_t * obj, lv_event_t event)
{
    if(event == LV_EVENT_VALUE_CHANGED) {
    	if(lv_switch_get_state(obj))
    		fio2_sw_toogle = 1;
    	else
    		fio2_sw_toogle = 0;
    }
}

// Encoder and groups
static lv_group_t*  homeGrp;
static lv_indev_t * enc_indev;

void setHomeGroupFocus()
{
	lv_indev_set_group(enc_indev, homeGrp);
}

void setGroupFocus(lv_group_t *grp)
{
	lv_indev_set_group(enc_indev, grp);
}

bool enc_pressed()
{
	int stateOfPushButton = HAL_GPIO_ReadPin(ENC_BTN_GPIO_Port,ENC_BTN_Pin);
	return !stateOfPushButton;
}

int enc_get_count(){
    int16_t count;
    count = TIM2->CNT;
    return count/4;
}

bool encoder_read_chip(lv_indev_drv_t * indev_drv, lv_indev_data_t * data)
{
	static int32_t last_encoder_diff = 0;
	int32_t encoder_val = enc_get_count();
	int32_t encoder_diff = encoder_val - last_encoder_diff;
	data->enc_diff  = encoder_diff;
	last_encoder_diff = encoder_val;

	if(enc_pressed())
		data->state = LV_INDEV_STATE_PR;
	else
		data->state = LV_INDEV_STATE_REL;
    return false;
}

void ARIES_Monitor(void)
{
	//Screen created here
	lv_obj_t * scr = lv_obj_create(NULL, NULL);
    lv_scr_load(scr);

    //encoder
    lv_indev_drv_t enc_drv;
     lv_indev_drv_init(&enc_drv);
     enc_drv.type = LV_INDEV_TYPE_ENCODER;
     enc_drv.read_cb = encoder_read_chip;
     enc_indev = lv_indev_drv_register(&enc_drv);

     lv_obj_t * scr_ev600a = lv_scr_act();
     lv_obj_set_pos(scr_ev600a, 0, 0);
     lv_obj_set_size(scr_ev600a, LV_HOR_RES_MAX, LV_VER_RES_MAX);
     lv_obj_set_style_local_bg_color(scr_ev600a, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,LV_COLOR_BLACK);
/*
     bg_top = lv_obj_create(lv_scr_act(), NULL);
     lv_obj_set_pos(bg_top, 0, 0);
     lv_obj_set_size(bg_top, LV_HOR_RES_MAX, LV_VER_RES_MAX);
     lv_obj_set_style_local_bg_color(bg_top, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,LV_COLOR_BLACK);
     lv_obj_set_style_local_line_color(bg_top, LV_CHART_AXIS_PRIMARY_Y, LV_STATE_DEFAULT, LV_COLOR_BLACK);
     lv_obj_set_style_local_border_width(bg_top, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,5);
     lv_obj_set_style_local_border_color(bg_top, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_BLACK);
     lv_obj_set_style_local_border_width(bg_top, LV_OBJ_PART_MAIN, LV_STATE_FOCUSED,5);
     lv_obj_set_style_local_border_color(bg_top, LV_OBJ_PART_MAIN, LV_STATE_FOCUSED, LV_COLOR_BLACK);*/

	   //graph layout change here
	    lv_obj_t *cont = lv_cont_create(lv_scr_act(), NULL);
	    lv_obj_set_size(cont, 600, 420);
	    lv_obj_set_pos(cont, 200, 60);
	    lv_obj_set_style_local_bg_color(cont, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,LV_COLOR_BLACK);
	    lv_obj_set_style_local_border_width(cont, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,0);

	    // TEMP chart label
		lv_obj_t * ptext = lv_label_create(cont, NULL);
	    lv_obj_set_pos(ptext, 50, 10 );
		lv_label_set_text(ptext,"TEMP");
		lv_obj_set_style_local_text_color(ptext, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);
	    //TEMP Chart Object
		pchart = lv_chart_create(cont, NULL);
	    lv_obj_set_size(pchart, 580, 100 );
	    lv_obj_set_pos(pchart, 20, 30 );
	    lv_chart_set_type(pchart, LV_CHART_TYPE_LINE);
	    lv_chart_set_update_mode(pchart, LV_CHART_UPDATE_MODE_CIRCULAR);
		pseries = lv_chart_add_series(pchart, EV600A_vl_graph);
		lv_chart_set_point_count(pchart, 100);
		ARIES_applychartstyles(pchart);
	    lv_obj_set_style_local_bg_color(pchart, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,EV600A_MONITOR_RECTANGLE_OUTLINE);
		lv_chart_set_y_tick_texts(pchart,"12\n\n\n\n50\n\n\n\n\n0",4,LV_CHART_AXIS_DRAW_LAST_TICK);

	    // HUMUDITY chart label
		lv_obj_t * vtext = lv_label_create(cont, NULL);
	    lv_obj_set_pos(vtext, 50, 130 );
		lv_label_set_text(vtext,"HUMUDITY");
		lv_obj_set_style_local_text_color(vtext, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);
	    //HUMUDITY Chart Object
		vchart = lv_chart_create(cont, NULL);
	    lv_obj_set_size(vchart, 580, 100 );
	    lv_obj_set_pos(vchart, 10, 150 );
	    lv_chart_set_type(vchart, LV_CHART_TYPE_LINE);
	    lv_chart_set_update_mode(vchart, LV_CHART_UPDATE_MODE_CIRCULAR);
		vseries = lv_chart_add_series(vchart, EV600A_vl_graph);
		lv_chart_set_point_count(vchart, 100);
		ARIES_applychartstyles(vchart);
		lv_obj_set_style_local_bg_color(vchart, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,EV600A_MONITOR_RECTANGLE_OUTLINE);
		lv_chart_set_y_tick_texts(vchart,"100\n\n\n\n50\n\n\n\n\n0",4,LV_CHART_AXIS_DRAW_LAST_TICK);


	    // SPO2 chart label
		lv_obj_t * ftext = lv_label_create(cont, NULL);
	    lv_obj_set_pos(ftext, 50, 260 );
		lv_label_set_text(ftext,"SPO2");
		lv_obj_set_style_local_text_color(ftext, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);
	    //Flow Chart Object
		fchart = lv_chart_create(cont, NULL);
	    lv_obj_set_size(fchart, 580, 90 );
	    lv_obj_set_pos(fchart, 10, 290 );
	    lv_chart_set_type(fchart, LV_CHART_TYPE_LINE);
	    lv_chart_set_update_mode(fchart, LV_CHART_UPDATE_MODE_CIRCULAR);
		fseries = lv_chart_add_series(fchart, EV600A_vl_graph);
		lv_chart_set_point_count(fchart, 100);
		ARIES_applychartstyles(fchart);
		lv_obj_set_style_local_bg_color(fchart, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,EV600A_MONITOR_RECTANGLE_OUTLINE);
		lv_chart_set_y_tick_texts(fchart,"100\n\n\n\n50\n\n\n\n\n0",4,LV_CHART_AXIS_DRAW_LAST_TICK);

		//FIO2  sw
		SW1_sw = lv_switch_create(lv_scr_act(), NULL);
		lv_switch_on(SW1_sw, LV_ANIM_OFF);
		 lv_obj_set_event_cb(SW1_sw, FIO2_sw_event_handler);
		lv_obj_set_pos(SW1_sw, LV_DPX(140), LV_DPX(260));
		lv_obj_set_size(SW1_sw, 70, 30);
		lv_obj_set_style_local_value_align(SW1_sw, LV_SWITCH_PART_BG, LV_STATE_DEFAULT, LV_ALIGN_OUT_RIGHT_MID);
		lv_obj_set_style_local_value_ofs_x(SW1_sw, LV_SWITCH_PART_BG, LV_STATE_DEFAULT, LV_DPI/35);
		lv_obj_set_style_local_bg_color(SW1_sw, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_GRAY);
	    lv_obj_set_style_local_border_width(SW1_sw, LV_OBJ_PART_MAIN, LV_STATE_FOCUSED ,3);
	    lv_obj_set_style_local_border_width(SW1_sw, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT ,3);

		//GAS  sw
		SW2_sw = lv_switch_create(lv_scr_act(), NULL);
		lv_switch_on(SW2_sw, LV_ANIM_OFF);
		lv_obj_set_event_cb(SW2_sw,GAS_sw_event_handler);
		lv_obj_set_pos(SW2_sw, LV_DPX(140), LV_DPX(205));
		lv_obj_set_size(SW2_sw, 70, 30);
		lv_obj_set_style_local_value_align(SW2_sw, LV_SWITCH_PART_BG, LV_STATE_DEFAULT, LV_ALIGN_OUT_RIGHT_MID);
		lv_obj_set_style_local_value_ofs_x(SW2_sw, LV_SWITCH_PART_BG, LV_STATE_DEFAULT, LV_DPI/35);
		lv_obj_set_style_local_bg_color(SW2_sw, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_GRAY);
		lv_obj_set_style_local_border_width(SW2_sw, LV_OBJ_PART_MAIN, LV_STATE_FOCUSED ,3);
		lv_obj_set_style_local_border_width(SW2_sw, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT ,3);

    BPM_set = lv_cont_create(lv_scr_act(),NULL);
    lv_obj_set_pos(BPM_set, 7, 495);
    lv_obj_set_size(BPM_set, 140, 100);
    lv_obj_set_style_local_border_width(BPM_set, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,2);
    set_parameter_button(BPM_set);

    TEMP_set = lv_cont_create(lv_scr_act(),NULL);
    lv_obj_set_pos(TEMP_set, 152, 495);
    lv_obj_set_size(TEMP_set, 140, 100);
    lv_obj_set_style_local_border_width(TEMP_set, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,2);
    set_parameter_button(TEMP_set);

    HUMIDITY_set = lv_cont_create(lv_scr_act(),NULL);
    lv_obj_set_pos(HUMIDITY_set, 297, 495);
    lv_obj_set_size(HUMIDITY_set, 140, 100);
    lv_obj_set_style_local_border_width(HUMIDITY_set, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,2);
    set_parameter_button(HUMIDITY_set);

    SPO2_set = lv_cont_create(lv_scr_act(),NULL);
    lv_obj_set_pos(SPO2_set, 442, 495);
    lv_obj_set_size(SPO2_set, 140, 100);
    lv_obj_set_style_local_border_width(SPO2_set, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT,4);
    set_parameter_button(SPO2_set);

    //parameter name
    BPM_parameter_name = lv_label_create(lv_scr_act(), NULL);
    lv_obj_set_pos(BPM_parameter_name, 15, 500);
    lv_label_set_text(BPM_parameter_name,"BPM");
    lv_obj_set_style_local_text_font(BPM_parameter_name, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_14);
    lv_obj_set_style_local_text_color(BPM_parameter_name, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

    TEMP_parameter_name = lv_label_create(lv_scr_act(), NULL);
    lv_obj_set_pos(TEMP_parameter_name, 160, 500);
    lv_label_set_text(TEMP_parameter_name,"TEMP");
    lv_obj_set_style_local_text_font(TEMP_parameter_name, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_14);
    lv_obj_set_style_local_text_color(TEMP_parameter_name, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

    HUMIDITY_parameter_name = lv_label_create(lv_scr_act(), NULL);
    lv_obj_set_pos(HUMIDITY_parameter_name, 305, 500);
    lv_label_set_text(HUMIDITY_parameter_name,"HUMIDITY");
    lv_obj_set_style_local_text_font(HUMIDITY_parameter_name, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_14);
    lv_obj_set_style_local_text_color(HUMIDITY_parameter_name, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

    SPO2_parameter_name = lv_label_create(lv_scr_act(), NULL);
    lv_obj_set_pos(SPO2_parameter_name, 450, 500);
    lv_label_set_text(SPO2_parameter_name,"SPO2");
    lv_obj_set_style_local_text_font(SPO2_parameter_name, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_14);
    lv_obj_set_style_local_text_color(SPO2_parameter_name, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

	BPM_monitor_data = lv_label_create(lv_scr_act(), NULL);
	lv_obj_set_pos(BPM_monitor_data, 55, 525);
	lv_label_set_text_fmt(BPM_monitor_data,"%d",100);
	lv_obj_set_style_local_text_font(BPM_monitor_data, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_42);
	lv_obj_set_style_local_text_color(BPM_monitor_data, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

    TEMP_monitor_data = lv_label_create(lv_scr_act(), NULL);
	lv_obj_set_pos(TEMP_monitor_data, 210, 525);
	lv_label_set_text_fmt(TEMP_monitor_data,"%d",12);
	lv_obj_set_style_local_text_font(TEMP_monitor_data, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_42);
	lv_obj_set_style_local_text_color(TEMP_monitor_data, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

    HUMIDITY_monitor_data = lv_label_create(lv_scr_act(), NULL);
    lv_obj_set_pos(HUMIDITY_monitor_data, 315, 525);
	lv_label_set_text_fmt(HUMIDITY_monitor_data,"%d",100);
	lv_obj_set_style_local_text_font(HUMIDITY_monitor_data, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_42);
	lv_obj_set_style_local_text_color(HUMIDITY_monitor_data, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

	SPO2_monitor_data = lv_label_create(lv_scr_act(), NULL);
	lv_obj_set_pos(SPO2_monitor_data, 500, 525);
	lv_label_set_text_fmt(SPO2_monitor_data,"%d",0);
	lv_obj_set_style_local_text_font(SPO2_monitor_data, LV_OBJ_PART_MAIN, LV_STATE_DEFAULT, &lv_font_montserrat_42);
	lv_obj_set_style_local_text_color(SPO2_monitor_data, LV_LABEL_PART_MAIN, LV_STATE_DEFAULT, LV_COLOR_WHITE);

    // Display Values
    lv_create_valdisplay(&TEMP_VAL, AR_VENT_PEEP);
    lv_create_valdisplay(&HUMIDITY_VAL, AR_VENT_RRATE);
    lv_create_valdisplay(&SPO2_VAL, AR_VENT_MINVOL);
    lv_create_valdisplay(&BPM_VAL, AR_VENT_FIO2);

    //display Value Positions
    lv_set_valdisplay_pos(&TEMP_VAL, 810, 60);
    lv_set_valdisplay_pos(&HUMIDITY_VAL, 810, 145);
    lv_set_valdisplay_pos(&SPO2_VAL, 810, 230);
    lv_set_valdisplay_pos(&BPM_VAL, 810, 315);

    //lv_group with highest priority also not solved issue .50% only solve
/*
    homeGrp = lv_group_create();
    lv_group_add_obj(homeGrp,SW1_sw);
    lv_group_add_obj(homeGrp,SW2_sw);
    lv_group_add_obj(homeGrp,BPM_set);
    lv_group_add_obj(homeGrp,TEMP_set);
    lv_group_add_obj(homeGrp,IE_set);
    lv_indev_set_group(enc_indev, homeGrp);*/

}
